summaryrefslogtreecommitdiff
path: root/gxp-platform.c
diff options
context:
space:
mode:
authorRobin Peng <robinpeng@google.com>2022-05-30 18:32:56 +0800
committerRobin Peng <robinpeng@google.com>2022-05-30 18:32:56 +0800
commit78604a94057626ed2d19da08ef15765beb8d4686 (patch)
tree07970abc5a3c639a8afb4eaf5fa0dbf65b1bf6f4 /gxp-platform.c
parent35e3403a4d6660b3db2e434d5fa93e23961222ec (diff)
parentb16f2fa6d4a747b68c8eab8fefb4dd94537d5426 (diff)
downloadgs201-78604a94057626ed2d19da08ef15765beb8d4686.tar.gz
Merge android13-gs-pixel-5.10-tm-d1 into android13-gs-pixel-5.10-tm-qpr1
Bug: 233569354 Signed-off-by: Robin Peng <robinpeng@google.com> Change-Id: Id0524ac1ee83e75bf5d3c6c951415cb01ad77fa2
Diffstat (limited to 'gxp-platform.c')
-rw-r--r--gxp-platform.c7
1 files changed, 5 insertions, 2 deletions
diff --git a/gxp-platform.c b/gxp-platform.c
index 36ae93d..46fb5bb 100644
--- a/gxp-platform.c
+++ b/gxp-platform.c
@@ -22,6 +22,7 @@
#include <linux/of_device.h>
#include <linux/platform_device.h>
#include <linux/pm_runtime.h>
+#include <linux/sched.h>
#include <linux/uaccess.h>
#include <linux/uidgid.h>
#if (IS_ENABLED(CONFIG_GXP_TEST) || IS_ENABLED(CONFIG_ANDROID)) && !IS_ENABLED(CONFIG_GXP_GEM5)
@@ -159,6 +160,7 @@ static int gxp_open(struct inode *inode, struct file *file)
if (IS_ERR(client))
return PTR_ERR(client);
+ client->tgid = current->tgid;
client->pid = current->pid;
file->private_data = client;
@@ -1277,9 +1279,10 @@ static int gxp_acquire_wake_lock_compat(
client->has_block_wakelock = true;
/*
* Update client's PID in case the process that opened /dev/gxp
* is not the one that called this IOCTL.
*/
+ client->tgid = current->tgid;
client->pid = current->pid;
}
@@ -1277,9 +1279,10 @@ static int gxp_acquire_wake_lock_compat(
client->has_block_wakelock = true;
/*
- * Update client's PID in case the process that opened /dev/gxp
- * is not the one that called this IOCTL.
+ * Update client's TGID/PID in case the process that opened
+ * /dev/gxp is not the one that called this IOCTL.
*/